@@ -33,9 +33,10 @@
 #  define PURPOSE_DEPRECATED_NO_EXPORT PURPOSE_NO_EXPORT PURPOSE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define PURPOSE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef PURPOSE_NO_DEPRECATED
+#    define PURPOSE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
